@@ -18,4 +18,11 @@ class TranslatorABC(ABC):
         Translate text.
         """
         pass
+
+    @abstractmethod
+    async def detect(self, text: str):
+        """
+        Detect language of text.
+        """
+        pass
     
\ No newline at end of file
